summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
Diffstat (limited to 'generic')
-rw-r--r--generic/regcomp.c4
-rw-r--r--generic/regerror.c6
-rw-r--r--generic/tclBasic.c4
-rw-r--r--generic/tclCkalloc.c2
-rw-r--r--generic/tclClock.c6
-rw-r--r--generic/tclCompCmdsSZ.c6
-rw-r--r--generic/tclCompile.h2
-rw-r--r--generic/tclDisassemble.c14
-rw-r--r--generic/tclEncoding.c4
-rw-r--r--generic/tclHash.c8
-rw-r--r--generic/tclIO.c20
-rw-r--r--generic/tclIO.h14
-rw-r--r--generic/tclIORChan.c23
-rw-r--r--generic/tclInt.h1
-rw-r--r--generic/tclInterp.c2
-rw-r--r--generic/tclLiteral.c8
-rw-r--r--generic/tclOO.c2
-rw-r--r--generic/tclOOInt.h36
-rw-r--r--generic/tclRegexp.c2
-rw-r--r--generic/tclStrToD.c2
-rw-r--r--generic/tclStringObj.c6
-rw-r--r--generic/tclTest.c30
-rw-r--r--generic/tclTestObj.c2
-rw-r--r--generic/tclTestProcBodyObj.c4
-rw-r--r--generic/tclThreadAlloc.c4
-rw-r--r--generic/tclThreadTest.c4
-rw-r--r--generic/tclUtil.c2
-rw-r--r--generic/tclZipfs.c2
-rw-r--r--generic/tclZlib.c6
29 files changed, 112 insertions, 114 deletions
diff --git a/generic/regcomp.c b/generic/regcomp.c
index 9ecc8c6..012e37c 100644
--- a/generic/regcomp.c
+++ b/generic/regcomp.c
@@ -2184,9 +2184,9 @@ stid(
return "unable";
}
if (t->id != 0) {
- sprintf(buf, "%d", t->id);
+ snprintf(buf, bufsize, "%d", t->id);
} else {
- sprintf(buf, "%p", t);
+ snprintf(buf, bufsize, "%p", t);
}
return buf;
}
diff --git a/generic/regerror.c b/generic/regerror.c
index a53a0fd..5caab8a 100644
--- a/generic/regerror.c
+++ b/generic/regerror.c
@@ -73,7 +73,7 @@ regerror(
break;
}
}
- sprintf(convbuf, "%d", r->code); /* -1 for unknown */
+ snprintf(convbuf, sizeof(convbuf), "%d", r->code); /* -1 for unknown */
msg = convbuf;
break;
case REG_ITOA: /* Convert number to name */
@@ -86,7 +86,7 @@ regerror(
if (r->code >= 0) {
msg = r->name;
} else { /* Unknown; tell him the number */
- sprintf(convbuf, "REG_%u", icode);
+ snprintf(convbuf, sizeof(convbuf), "REG_%u", icode);
msg = convbuf;
}
break;
@@ -99,7 +99,7 @@ regerror(
if (r->code >= 0) {
msg = r->explain;
} else { /* Unknown; say so */
- sprintf(convbuf, unk, code);
+ snprintf(convbuf, sizeof(convbuf), unk, code);
msg = convbuf;
}
break;
diff --git a/generic/tclBasic.c b/generic/tclBasic.c
index 9b1b5a5..1d78e7e 100644
--- a/generic/tclBasic.c
+++ b/generic/tclBasic.c
@@ -1499,7 +1499,7 @@ Tcl_CallWhenDeleted(
AssocData *dPtr = (AssocData *)Tcl_Alloc(sizeof(AssocData));
Tcl_HashEntry *hPtr;
- sprintf(buffer, "Assoc Data Key #%d", *assocDataCounterPtr);
+ snprintf(buffer, sizeof(buffer), "Assoc Data Key #%d", *assocDataCounterPtr);
(*assocDataCounterPtr)++;
if (iPtr->assocData == NULL) {
@@ -6369,7 +6369,7 @@ ProcessUnexpectedResult(
Tcl_SetObjResult(interp, Tcl_ObjPrintf(
"command returned bad code: %d", returnCode));
}
- sprintf(buf, "%d", returnCode);
+ snprintf(buf, sizeof(buf), "%d", returnCode);
Tcl_SetErrorCode(interp, "TCL", "UNEXPECTED_RESULT_CODE", buf, NULL);
}
diff --git a/generic/tclCkalloc.c b/generic/tclCkalloc.c
index 6f31940..f81cf60 100644
--- a/generic/tclCkalloc.c
+++ b/generic/tclCkalloc.c
@@ -172,7 +172,7 @@ TclDumpMemoryInfo(
if (clientData == NULL) {
return 0;
}
- sprintf(buf,
+ snprintf(buf, sizeof(buf),
"total mallocs %10" TCL_Z_MODIFIER "u\n"
"total frees %10" TCL_Z_MODIFIER "u\n"
"current packets allocated %10" TCL_Z_MODIFIER "u\n"
diff --git a/generic/tclClock.c b/generic/tclClock.c
index 1d33886..ef11a2f 100644
--- a/generic/tclClock.c
+++ b/generic/tclClock.c
@@ -1086,12 +1086,12 @@ ConvertUTCToLocalUsingC(
} else {
*buffer = '+';
}
- sprintf(buffer+1, "%02d", diff / 3600);
+ snprintf(buffer+1, sizeof(buffer) - 1, "%02d", diff / 3600);
diff %= 3600;
- sprintf(buffer+3, "%02d", diff / 60);
+ snprintf(buffer+3, sizeof(buffer) - 3, "%02d", diff / 60);
diff %= 60;
if (diff > 0) {
- sprintf(buffer+5, "%02d", diff);
+ snprintf(buffer+5, sizeof(buffer) - 5, "%02d", diff);
}
fields->tzName = Tcl_NewStringObj(buffer, -1);
Tcl_IncrRefCount(fields->tzName);
diff --git a/generic/tclCompCmdsSZ.c b/generic/tclCompCmdsSZ.c
index c8fa120..47999d9 100644
--- a/generic/tclCompCmdsSZ.c
+++ b/generic/tclCompCmdsSZ.c
@@ -897,7 +897,7 @@ TclCompileStringLenCmd(
char buf[TCL_INTEGER_SPACE];
size_t len = Tcl_GetCharLength(objPtr);
- len = sprintf(buf, "%" TCL_Z_MODIFIER "u", len);
+ len = snprintf(buf, sizeof(buf), "%" TCL_Z_MODIFIER "u", len);
PushLiteral(envPtr, buf, len);
} else {
SetLineInformation(1);
@@ -3124,7 +3124,7 @@ IssueTryClausesInstructions(
for (i=0 ; i<numHandlers ; i++) {
noError[i] = -1;
- sprintf(buf, "%d", matchCodes[i]);
+ snprintf(buf, sizeof(buf), "%d", matchCodes[i]);
OP( DUP);
PushLiteral(envPtr, buf, strlen(buf));
OP( EQ);
@@ -3337,7 +3337,7 @@ IssueTryClausesFinallyInstructions(
int noTrapError, trapError;
const char *p;
- sprintf(buf, "%d", matchCodes[i]);
+ snprintf(buf, sizeof(buf), "%d", matchCodes[i]);
OP( DUP);
PushLiteral(envPtr, buf, strlen(buf));
OP( EQ);
diff --git a/generic/tclCompile.h b/generic/tclCompile.h
index 035edac..24bc604 100644
--- a/generic/tclCompile.h
+++ b/generic/tclCompile.h
@@ -1817,7 +1817,7 @@ MODULE_SCOPE void TclDTraceInfo(Tcl_Obj *info, const char **args, int *argsi);
FILE *tclDTraceDebugLog = NULL; \
void TclDTraceOpenDebugLog(void) { \
char n[35]; \
- sprintf(n, "/tmp/tclDTraceDebug-%" TCL_Z_MODIFIER "u.log", \
+ snprintf(n, sizeof(n), "/tmp/tclDTraceDebug-%" TCL_Z_MODIFIER "u.log", \
(size_t) getpid()); \
tclDTraceDebugLog = fopen(n, "a"); \
}
diff --git a/generic/tclDisassemble.c b/generic/tclDisassemble.c
index c06731f..f1d974b 100644
--- a/generic/tclDisassemble.c
+++ b/generic/tclDisassemble.c
@@ -571,22 +571,22 @@ FormatInstruction(
case OPERAND_UINT4:
opnd = TclGetUInt4AtPtr(pc+numBytes); numBytes += 4;
if (opCode == INST_START_CMD) {
- sprintf(suffixBuffer+strlen(suffixBuffer),
+ snprintf(suffixBuffer+strlen(suffixBuffer), sizeof(suffixBuffer) - strlen(suffixBuffer),
", %u cmds start here", opnd);
}
Tcl_AppendPrintfToObj(bufferObj, "%u ", opnd);
break;
case OPERAND_OFFSET1:
opnd = TclGetInt1AtPtr(pc+numBytes); numBytes++;
- sprintf(suffixBuffer, "pc %u", pcOffset+opnd);
+ snprintf(suffixBuffer, sizeof(suffixBuffer), "pc %u", pcOffset+opnd);
Tcl_AppendPrintfToObj(bufferObj, "%+d ", opnd);
break;
case OPERAND_OFFSET4:
opnd = TclGetInt4AtPtr(pc+numBytes); numBytes += 4;
if (opCode == INST_START_CMD) {
- sprintf(suffixBuffer, "next cmd at pc %u", pcOffset+opnd);
+ snprintf(suffixBuffer, sizeof(suffixBuffer), "next cmd at pc %u", pcOffset+opnd);
} else {
- sprintf(suffixBuffer, "pc %u", pcOffset+opnd);
+ snprintf(suffixBuffer, sizeof(suffixBuffer), "pc %u", pcOffset+opnd);
}
Tcl_AppendPrintfToObj(bufferObj, "%+d ", opnd);
break;
@@ -632,9 +632,9 @@ FormatInstruction(
localPtr = localPtr->nextPtr;
}
if (TclIsVarTemporary(localPtr)) {
- sprintf(suffixBuffer, "temp var %u", opnd);
+ snprintf(suffixBuffer, sizeof(suffixBuffer), "temp var %u", opnd);
} else {
- sprintf(suffixBuffer, "var ");
+ snprintf(suffixBuffer, sizeof(suffixBuffer), "var ");
suffixSrc = localPtr->name;
}
}
@@ -836,7 +836,7 @@ UpdateStringOfInstName(
if (inst >= LAST_INST_OPCODE) {
dst = Tcl_InitStringRep(objPtr, NULL, TCL_INTEGER_SPACE + 5);
TclOOM(dst, TCL_INTEGER_SPACE + 5);
- sprintf(dst, "inst_%" TCL_Z_MODIFIER "u", inst);
+ snprintf(dst, TCL_INTEGER_SPACE + 5, "inst_%" TCL_Z_MODIFIER "u", inst);
(void) Tcl_InitStringRep(objPtr, NULL, strlen(dst));
} else {
const char *s = tclInstructionTable[inst].name;
diff --git a/generic/tclEncoding.c b/generic/tclEncoding.c
index 5c240e3..f8f4bf4 100644
--- a/generic/tclEncoding.c
+++ b/generic/tclEncoding.c
@@ -1288,7 +1288,7 @@ Tcl_ExternalToUtfDStringEx(
/* Caller wants error message on failure */
if (result != TCL_OK && interp != NULL) {
char buf[TCL_INTEGER_SPACE];
- sprintf(buf, "%" TCL_Z_MODIFIER "u", nBytesProcessed);
+ snprintf(buf, sizeof(buf), "%" TCL_Z_MODIFIER "u", nBytesProcessed);
Tcl_SetObjResult(
interp,
Tcl_ObjPrintf("unexpected byte sequence starting at index %"
@@ -1617,7 +1617,7 @@ Tcl_UtfToExternalDStringEx(
int ucs4;
char buf[TCL_INTEGER_SPACE];
TclUtfToUCS4(&srcStart[nBytesProcessed], &ucs4);
- sprintf(buf, "%" TCL_Z_MODIFIER "u", nBytesProcessed);
+ snprintf(buf, sizeof(buf), "%" TCL_Z_MODIFIER "u", nBytesProcessed);
Tcl_SetObjResult(
interp,
Tcl_ObjPrintf(
diff --git a/generic/tclHash.c b/generic/tclHash.c
index 5cfc63c..4b31971 100644
--- a/generic/tclHash.c
+++ b/generic/tclHash.c
@@ -623,18 +623,18 @@ Tcl_HashStats(
*/
result = (char *)Tcl_Alloc((NUM_COUNTERS * 60) + 300);
- sprintf(result, "%" TCL_Z_MODIFIER "u entries in table, %" TCL_Z_MODIFIER "u buckets\n",
+ snprintf(result, 60, "%" TCL_Z_MODIFIER "u entries in table, %" TCL_Z_MODIFIER "u buckets\n",
tablePtr->numEntries, tablePtr->numBuckets);
p = result + strlen(result);
for (i = 0; i < NUM_COUNTERS; i++) {
- sprintf(p, "number of buckets with %" TCL_Z_MODIFIER "u entries: %" TCL_Z_MODIFIER "u\n",
+ snprintf(p, 60, "number of buckets with %" TCL_Z_MODIFIER "u entries: %" TCL_Z_MODIFIER "u\n",
i, count[i]);
p += strlen(p);
}
- sprintf(p, "number of buckets with %d or more entries: %" TCL_Z_MODIFIER "u\n",
+ snprintf(p, 60, "number of buckets with %d or more entries: %" TCL_Z_MODIFIER "u\n",
NUM_COUNTERS, overflow);
p += strlen(p);
- sprintf(p, "average search distance for entry: %.1f", average);
+ snprintf(p, 60, "average search distance for entry: %.1f", average);
return result;
}
diff --git a/generic/tclIO.h b/generic/tclIO.h
index 67807c0..76269a1 100644
--- a/generic/tclIO.h
+++ b/generic/tclIO.h
@@ -36,12 +36,12 @@
*/
typedef struct ChannelBuffer {
- size_t refCount; /* Current uses count */
- size_t nextAdded; /* The next position into which a character
+ Tcl_Size refCount; /* Current uses count */
+ Tcl_Size nextAdded; /* The next position into which a character
* will be put in the buffer. */
- size_t nextRemoved; /* Position of next byte to be removed from
+ Tcl_Size nextRemoved; /* Position of next byte to be removed from
* the buffer. */
- size_t bufLength; /* How big is the buffer? */
+ Tcl_Size bufLength; /* How big is the buffer? */
struct ChannelBuffer *nextPtr;
/* Next buffer in chain. */
char buf[TCLFLEXARRAY]; /* Placeholder for real buffer. The real
@@ -113,7 +113,7 @@ typedef struct Channel {
ChannelBuffer *inQueueHead; /* Points at first buffer in input queue. */
ChannelBuffer *inQueueTail; /* Points at last buffer in input queue. */
- size_t refCount;
+ Tcl_Size refCount;
} Channel;
/*
@@ -165,7 +165,7 @@ typedef struct ChannelState {
int unreportedError; /* Non-zero if an error report was deferred
* because it happened in the background. The
* value is the POSIX error code. */
- size_t refCount; /* How many interpreters hold references to
+ Tcl_Size refCount; /* How many interpreters hold references to
* this IO channel? */
struct CloseCallback *closeCbPtr;
/* Callbacks registered to be called when the
@@ -188,7 +188,7 @@ typedef struct ChannelState {
EventScriptRecord *scriptRecordPtr;
/* Chain of all scripts registered for event
* handlers ("fileevent") on this channel. */
- size_t bufSize; /* What size buffers to allocate? */
+ Tcl_Size bufSize; /* What size buffers to allocate? */
Tcl_TimerToken timer; /* Handle to wakeup timer for this channel. */
Channel *timerChanPtr; /* Needed in order to decrement the refCount of
the right channel when the timer is
diff --git a/generic/tclIORChan.c b/generic/tclIORChan.c
index ba2d2cb..fcdb530 100644
--- a/generic/tclIORChan.c
+++ b/generic/tclIORChan.c
@@ -549,7 +549,7 @@ TclChanCreateObjCmd(
/*
* First argument is a list of modes. Allowed entries are "read", "write".
- * Expect at least one list element. Abbreviations are ok.
+ * Empty list is uncommon, but allowed. Abbreviations are ok.
*/
modeObj = objv[MODE];
@@ -922,6 +922,11 @@ TclChanPostEventObjCmd(
if (EncodeEventMask(interp, "event", objv[EVENT], &events) != TCL_OK) {
return TCL_ERROR;
}
+ if (events == 0) {
+ Tcl_SetObjResult(interp,
+ Tcl_NewStringObj("bad event list: is empty", -1));
+ return TCL_ERROR;
+ }
/*
* Check that the channel is actually interested in the provided events.
@@ -2111,10 +2116,10 @@ ReflectTruncate(
* EncodeEventMask --
*
* This function takes a list of event items and constructs the
- * equivalent internal bitmask. The list must contain at least one
- * element. Elements are "read", "write", or any unique abbreviation of
- * them. Note that the bitmask is not changed if problems are
- * encountered.
+ * equivalent internal bitmask. The list may be empty but will usually
+ * contain at least one element. Valid elements are "read", "write", or
+ * any unique abbreviation of them. Note that the bitmask is not changed
+ * if problems are encountered.
*
* Results:
* A standard Tcl error code. A bitmask where TCL_READABLE and/or
@@ -2144,12 +2149,6 @@ EncodeEventMask(
return TCL_ERROR;
}
- if (listc < 1) {
- Tcl_SetObjResult(interp, Tcl_ObjPrintf(
- "bad %s list: is empty", objName));
- return TCL_ERROR;
- }
-
events = 0;
while (listc > 0) {
if (Tcl_GetIndexFromObj(interp, listv[listc-1], eventOptions,
@@ -3321,7 +3320,7 @@ ForwardProc(
*/
char *buf = (char *)Tcl_Alloc(200);
- sprintf(buf,
+ snprintf(buf, 200,
"{Expected list with even number of elements, got %" TCL_Z_MODIFIER "u %s instead}",
listc, (listc == 1 ? "element" : "elements"));
diff --git a/generic/tclInt.h b/generic/tclInt.h
index 67424ad..57fe442 100644
--- a/generic/tclInt.h
+++ b/generic/tclInt.h
@@ -131,6 +131,7 @@
#if defined(_WIN32) && defined(_MSC_VER)
# define vsnprintf _vsnprintf
+# define snprintf _snprintf
#endif
#if !defined(TCL_THREADS)
diff --git a/generic/tclInterp.c b/generic/tclInterp.c
index 7c6c085..6fa9f61 100644
--- a/generic/tclInterp.c
+++ b/generic/tclInterp.c
@@ -832,7 +832,7 @@ NRInterpCmd(
for (i = 0; ; i++) {
Tcl_CmdInfo cmdInfo;
- sprintf(buf, "interp%d", i);
+ snprintf(buf, sizeof(buf), "interp%d", i);
if (Tcl_GetCommandInfo(interp, buf, &cmdInfo) == 0) {
break;
}
diff --git a/generic/tclLiteral.c b/generic/tclLiteral.c
index c3f0f7d..c189b50 100644
--- a/generic/tclLiteral.c
+++ b/generic/tclLiteral.c
@@ -1128,18 +1128,18 @@ TclLiteralStats(
*/
result = (char *)Tcl_Alloc(NUM_COUNTERS*60 + 300);
- sprintf(result, "%" TCL_Z_MODIFIER "u entries in table, %" TCL_Z_MODIFIER "u buckets\n",
+ snprintf(result, 60, "%" TCL_Z_MODIFIER "u entries in table, %" TCL_Z_MODIFIER "u buckets\n",
tablePtr->numEntries, tablePtr->numBuckets);
p = result + strlen(result);
for (i=0 ; i<NUM_COUNTERS ; i++) {
- sprintf(p, "number of buckets with %" TCL_Z_MODIFIER "u entries: %" TCL_Z_MODIFIER "u\n",
+ snprintf(p, 60, "number of buckets with %" TCL_Z_MODIFIER "u entries: %" TCL_Z_MODIFIER "u\n",
i, count[i]);
p += strlen(p);
}
- sprintf(p, "number of buckets with %d or more entries: %" TCL_Z_MODIFIER "u\n",
+ snprintf(p, 60, "number of buckets with %d or more entries: %" TCL_Z_MODIFIER "u\n",
NUM_COUNTERS, overflow);
p += strlen(p);
- sprintf(p, "average search distance for entry: %.1f", average);
+ snprintf(p, 60, "average search distance for entry: %.1f", average);
return result;
}
#endif /*TCL_COMPILE_STATS*/
diff --git a/generic/tclOO.c b/generic/tclOO.c
index bee06e2..6afa06b 100644
--- a/generic/tclOO.c
+++ b/generic/tclOO.c
@@ -654,7 +654,7 @@ AllocObject(
while (1) {
char objName[10 + TCL_INTEGER_SPACE];
- sprintf(objName, "::oo::Obj%" TCL_Z_MODIFIER "u", ++fPtr->tsdPtr->nsCount);
+ snprintf(objName, sizeof(objName), "::oo::Obj%" TCL_Z_MODIFIER "u", ++fPtr->tsdPtr->nsCount);
oPtr->namespacePtr = Tcl_CreateNamespace(interp, objName, oPtr, NULL);
if (oPtr->namespacePtr != NULL) {
creationEpoch = fPtr->tsdPtr->nsCount;
diff --git a/generic/tclOOInt.h b/generic/tclOOInt.h
index b7fb34d..29e3b13 100644
--- a/generic/tclOOInt.h
+++ b/generic/tclOOInt.h
@@ -46,7 +46,7 @@ typedef struct Method {
/* The type of method. If NULL, this is a
* special flag record which is just used for
* the setting of the flags field. */
- size_t refCount;
+ Tcl_Size refCount;
void *clientData; /* Type-specific data. */
Tcl_Obj *namePtr; /* Name of the method. */
struct Object *declaringObjectPtr;
@@ -83,7 +83,7 @@ typedef struct ProcedureMethod {
* includes the argument definition and the
* body bytecodes. */
int flags; /* Flags to control features. */
- size_t refCount;
+ Tcl_Size refCount;
void *clientData;
TclOO_PmCDDeleteProc *deleteClientdataProc;
TclOO_PmCDCloneProc *cloneClientdataProc;
@@ -149,9 +149,9 @@ typedef struct {
*/
#define LIST_STATIC(listType_t) \
- struct { size_t num; listType_t *list; }
+ struct { Tcl_Size num; listType_t *list; }
#define LIST_DYNAMIC(listType_t) \
- struct { size_t num, size; listType_t *list; }
+ struct { Tcl_Size num, size; listType_t *list; }
/*
* These types are needed in function arguments.
@@ -184,14 +184,14 @@ typedef struct Object {
struct Class *classPtr; /* This is non-NULL for all classes, and NULL
* for everything else. It points to the class
* structure. */
- size_t refCount; /* Number of strong references to this object.
+ Tcl_Size refCount; /* Number of strong references to this object.
* Note that there may be many more weak
* references; this mechanism exists to
* avoid Tcl_Preserve. */
int flags;
- size_t creationEpoch; /* Unique value to make comparisons of objects
+ Tcl_Size creationEpoch; /* Unique value to make comparisons of objects
* easier. */
- size_t epoch; /* Per-object epoch, incremented when the way
+ Tcl_Size epoch; /* Per-object epoch, incremented when the way
* an object should resolve call chains is
* changed. */
Tcl_HashTable *metadataPtr; /* Mapping from pointers to metadata type to
@@ -329,7 +329,7 @@ typedef struct Class {
*/
typedef struct ThreadLocalData {
- size_t nsCount; /* Epoch counter is used for keeping
+ Tcl_Size nsCount; /* Epoch counter is used for keeping
* the values used in Tcl_Obj internal
* representations sane. Must be thread-local
* because Tcl_Objs can cross interpreter
@@ -353,7 +353,7 @@ typedef struct Foundation {
Tcl_Namespace *helpersNs; /* Namespace containing the commands that are
* only valid when executing inside a
* procedural method. */
- size_t epoch; /* Used to invalidate method chains when the
+ Tcl_Size epoch; /* Used to invalidate method chains when the
* class structure changes. */
ThreadLocalData *tsdPtr; /* Counter so we can allocate a unique
* namespace to each object. */
@@ -387,16 +387,16 @@ struct MInvoke {
};
typedef struct CallChain {
- size_t objectCreationEpoch; /* The object's creation epoch. Note that the
+ Tcl_Size objectCreationEpoch; /* The object's creation epoch. Note that the
* object reference is not stored in the call
* chain; it is in the call context. */
- size_t objectEpoch; /* Local (object structure) epoch counter
+ Tcl_Size objectEpoch; /* Local (object structure) epoch counter
* snapshot. */
- size_t epoch; /* Global (class structure) epoch counter
+ Tcl_Size epoch; /* Global (class structure) epoch counter
* snapshot. */
int flags; /* Assorted flags, see below. */
- size_t refCount; /* Reference count. */
- size_t numChain; /* Size of the call chain. */
+ Tcl_Size refCount; /* Reference count. */
+ Tcl_Size numChain; /* Size of the call chain. */
struct MInvoke *chain; /* Array of call chain entries. May point to
* staticChain if the number of entries is
* small. */
@@ -405,9 +405,9 @@ typedef struct CallChain {
typedef struct CallContext {
Object *oPtr; /* The object associated with this call. */
- size_t index; /* Index into the call chain of the currently
+ Tcl_Size index; /* Index into the call chain of the currently
* executing method implementation. */
- size_t skip; /* Current number of arguments to skip; can
+ Tcl_Size skip; /* Current number of arguments to skip; can
* vary depending on whether it is a direct
* method call or a continuation via the
* [next] command. */
@@ -578,7 +578,7 @@ MODULE_SCOPE void TclOOSetupVariableResolver(Tcl_Namespace *nsPtr);
/*
* A convenience macro for iterating through the lists used in the internal
* memory management of objects.
- * REQUIRES DECLARATION: size_t i;
+ * REQUIRES DECLARATION: Tcl_Size i;
*/
#define FOREACH(var,ary) \
@@ -590,7 +590,7 @@ MODULE_SCOPE void TclOOSetupVariableResolver(Tcl_Namespace *nsPtr);
* A variation where the array is an array of structs. There's no issue with
* possible NULLs; every element of the array will be iterated over and the
* varable set to a pointer to each of those elements in turn.
- * REQUIRES DECLARATION: size_t i;
+ * REQUIRES DECLARATION: Tcl_Size i;
*/
#define FOREACH_STRUCT(var,ary) \
diff --git a/generic/tclRegexp.c b/generic/tclRegexp.c
index 07beffd..35f6334 100644
--- a/generic/tclRegexp.c
+++ b/generic/tclRegexp.c
@@ -730,7 +730,7 @@ TclRegError(
p = (n > sizeof(buf)) ? "..." : "";
Tcl_SetObjResult(interp, Tcl_ObjPrintf("%s%s%s", msg, buf, p));
- sprintf(cbuf, "%d", status);
+ snprintf(cbuf, sizeof(cbuf), "%d", status);
(void) TclReError(REG_ITOA, cbuf, sizeof(cbuf));
Tcl_SetErrorCode(interp, "REGEXP", cbuf, buf, NULL);
}
diff --git a/generic/tclStrToD.c b/generic/tclStrToD.c
index 2f29617..5d2efc7 100644
--- a/generic/tclStrToD.c
+++ b/generic/tclStrToD.c
@@ -5273,7 +5273,7 @@ TclFormatNaN(
*buffer++ = 'N';
bitwhack.iv &= ((UINT64_C(1)) << 51) - 1;
if (bitwhack.iv != 0) {
- sprintf(buffer, "(%" PRIx64 ")", bitwhack.iv);
+ snprintf(buffer, TCL_DOUBLE_SPACE, "(%" PRIx64 ")", bitwhack.iv);
} else {
*buffer = '\0';
}
diff --git a/generic/tclStringObj.c b/generic/tclStringObj.c
index 34b185d..959a221 100644
--- a/generic/tclStringObj.c
+++ b/generic/tclStringObj.c
@@ -2481,14 +2481,14 @@ Tcl_AppendFormatToObj(
*p++ = '+';
}
if (width) {
- p += sprintf(p, "%d", width);
+ p += snprintf(p, TCL_INTEGER_SPACE, "%d", width);
if (width > length) {
length = width;
}
}
if (gotPrecision) {
*p++ = '.';
- p += sprintf(p, "%d", precision);
+ p += snprintf(p, TCL_INTEGER_SPACE, "%d", precision);
if (precision > INT_MAX - length) {
msg = overflow;
errCode = "OVERFLOW";
@@ -2512,7 +2512,7 @@ Tcl_AppendFormatToObj(
goto errorMsg;
}
bytes = TclGetString(segment);
- if (!Tcl_AttemptSetObjLength(segment, sprintf(bytes, spec, d))) {
+ if (!Tcl_AttemptSetObjLength(segment, snprintf(bytes, segment->length, spec, d))) {
msg = overflow;
errCode = "OVERFLOW";
goto errorMsg;
diff --git a/generic/tclTestObj.c b/generic/tclTestObj.c
index 42a96da..52dd53d 100644
--- a/generic/tclTestObj.c
+++ b/generic/tclTestObj.c
@@ -1618,7 +1618,7 @@ CheckIfVarUnset(
if (varPtr[varIndex] == NULL) {
char buf[32 + TCL_INTEGER_SPACE];
- sprintf(buf, "variable %" TCL_Z_MODIFIER "u is unset (NULL)", varIndex);
+ snprintf(buf, sizeof(buf), "variable %" TCL_Z_MODIFIER "u is unset (NULL)", varIndex);
Tcl_ResetResult(interp);
Tcl_AppendToObj(Tcl_GetObjResult(interp), buf, TCL_INDEX_NONE);
return 1;
diff --git a/generic/tclTestProcBodyObj.c b/generic/tclTestProcBodyObj.c
index 8d92c6e..381ff02 100644
--- a/generic/tclTestProcBodyObj.c
+++ b/generic/tclTestProcBodyObj.c
@@ -144,14 +144,14 @@ RegisterCommand(
char buf[128];
if (cmdTablePtr->exportIt) {
- sprintf(buf, "namespace eval %s { namespace export %s }",
+ snprintf(buf, sizeof(buf), "namespace eval %s { namespace export %s }",
namesp, cmdTablePtr->cmdName);
if (Tcl_EvalEx(interp, buf, TCL_INDEX_NONE, 0) != TCL_OK) {
return TCL_ERROR;
}
}
- sprintf(buf, "%s::%s", namesp, cmdTablePtr->cmdName);
+ snprintf(buf, sizeof(buf), "%s::%s", namesp, cmdTablePtr->cmdName);
Tcl_CreateObjCommand(interp, buf, cmdTablePtr->proc, 0, 0);
return TCL_OK;
}
diff --git a/generic/tclThreadAlloc.c b/generic/tclThreadAlloc.c
index 1eb6315..5329991 100644
--- a/generic/tclThreadAlloc.c
+++ b/generic/tclThreadAlloc.c
@@ -640,11 +640,11 @@ Tcl_GetMemoryInfo(
if (cachePtr == sharedPtr) {
Tcl_DStringAppendElement(dsPtr, "shared");
} else {
- sprintf(buf, "thread%p", cachePtr->owner);
+ snprintf(buf, sizeof(buf), "thread%p", cachePtr->owner);
Tcl_DStringAppendElement(dsPtr, buf);
}
for (n = 0; n < NBUCKETS; ++n) {
- sprintf(buf, "%" TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u %"
+ snprintf(buf, sizeof(buf), "%" TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u %"
TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u %" TCL_Z_MODIFIER "u",
bucketInfo[n].blockSize,
cachePtr->buckets[n].numFree,
diff --git a/generic/tclThreadTest.c b/generic/tclThreadTest.c
index 5781329..a5b079a 100644
--- a/generic/tclThreadTest.c
+++ b/generic/tclThreadTest.c
@@ -367,7 +367,7 @@ ThreadObjCmd(
} else {
char buf[TCL_INTEGER_SPACE];
- sprintf(buf, "%" TCL_LL_MODIFIER "d", (long long)id);
+ snprintf(buf, sizeof(buf), "%" TCL_LL_MODIFIER "d", (long long)id);
Tcl_AppendResult(interp, "cannot join thread ", buf, NULL);
}
return result;
@@ -649,7 +649,7 @@ ThreadErrorProc(
char *script;
char buf[TCL_DOUBLE_SPACE+1];
- sprintf(buf, "%p", Tcl_GetCurrentThread());
+ snprintf(buf, sizeof(buf), "%p", Tcl_GetCurrentThread());
errorInfo = Tcl_GetVar2(interp, "errorInfo", NULL, TCL_GLOBAL_ONLY);
if (errorProcString == NULL) {
diff --git a/generic/tclUtil.c b/generic/tclUtil.c
index d79fd97..c03ead9 100644
--- a/generic/tclUtil.c
+++ b/generic/tclUtil.c
@@ -3115,7 +3115,7 @@ Tcl_PrintDouble(
}
}
- sprintf(dst, "e%+d", exponent);
+ snprintf(dst, TCL_DOUBLE_SPACE, "e%+d", exponent);
} else {
/*
* F format for others.
diff --git a/generic/tclZipfs.c b/generic/tclZipfs.c
index 1653dbe..4345d00 100644
--- a/generic/tclZipfs.c
+++ b/generic/tclZipfs.c
@@ -4395,7 +4395,7 @@ ZipChannelOpen(
* Wrap the ZipChannel into a Tcl_Channel.
*/
- sprintf(cname, "zipfs_%" TCL_Z_MODIFIER "x_%d", z->offset,
+ snprintf(cname, sizeof(cname), "zipfs_%" TCL_Z_MODIFIER "x_%d", z->offset,
ZipFS.idCount++);
z->zipFilePtr->numOpen++;
Unlock();
diff --git a/generic/tclZlib.c b/generic/tclZlib.c
index e016fd0..2ad93ff 100644
--- a/generic/tclZlib.c
+++ b/generic/tclZlib.c
@@ -289,7 +289,7 @@ ConvertError(
case Z_NEED_DICT:
codeStr = "NEED_DICT";
codeStr2 = codeStrBuf;
- sprintf(codeStrBuf, "%lu", adler);
+ snprintf(codeStrBuf, sizeof(codeStrBuf), "%lu", adler);
break;
/*
@@ -310,7 +310,7 @@ ConvertError(
default:
codeStr = "UNKNOWN";
codeStr2 = codeStrBuf;
- sprintf(codeStrBuf, "%d", code);
+ snprintf(codeStrBuf, sizeof(codeStrBuf), "%d", code);
break;
}
Tcl_SetObjResult(interp, Tcl_NewStringObj(zError(code), TCL_INDEX_NONE));
@@ -3491,7 +3491,7 @@ ZlibTransformGetOption(
crc = cd->inStream.adler;
}
- sprintf(buf, "%lu", crc);
+ snprintf(buf, sizeof(buf), "%lu", crc);
if (optionName == NULL) {
Tcl_DStringAppendElement(dsPtr, "-checksum");
Tcl_DStringAppendElement(dsPtr, buf);
diff --git a/generic/tclIO.c b/generic/tclIO.c
index 7848fa4..4001798 100644
--- a/generic/tclIO.c
+++ b/generic/tclIO.c
@@ -4420,19 +4420,17 @@ Write(
* current output encoding and strict encoding is active.
*/
- if (result == TCL_CONVERT_UNKNOWN || result == TCL_CONVERT_SYNTAX) {
- encodingError = 1;
- result = TCL_OK;
- }
-
- if ((result != TCL_OK) && (srcRead + dstWrote == 0)) {
+ if (
+ (result == TCL_CONVERT_UNKNOWN || result == TCL_CONVERT_SYNTAX)
+ ||
/*
* We're reading from invalid/incomplete UTF-8.
*/
-
+ ((result != TCL_OK) && (srcRead + dstWrote == 0))
+ ) {
encodingError = 1;
result = TCL_OK;
- }
+ }
bufPtr->nextAdded += dstWrote;
src += srcRead;
@@ -4489,7 +4487,7 @@ Write(
* beginning of the next buffer.
*/
- saved = 1 + ~SpaceLeft(bufPtr);
+ saved = -SpaceLeft(bufPtr);
memcpy(safe, dst + dstLen, saved);
bufPtr->nextAdded = bufPtr->bufLength;
}
@@ -7910,7 +7908,7 @@ Tcl_GetChannelOption(
Tcl_DString *dsPtr) /* Where to store value(s). */
{
size_t len; /* Length of optionName string. */
- char optionVal[128]; /* Buffer for sprintf. */
+ char optionVal[128]; /* Buffer for snprintf. */
Channel *chanPtr = (Channel *) chan;
ChannelState *statePtr = chanPtr->state;
/* State info for channel */
@@ -8011,7 +8009,7 @@ Tcl_GetChannelOption(
Tcl_DStringAppendElement(dsPtr, "-eofchar");
}
if ((flags & TCL_READABLE) && (statePtr->inEofChar != 0)) {
- sprintf(buf, "%c", statePtr->inEofChar);
+ snprintf(buf, sizeof(buf), "%c", statePtr->inEofChar);
}
if (len > 0) {
Tcl_DStringAppend(dsPtr, buf, TCL_INDEX_NONE);
diff --git a/generic/tclTest.c b/generic/tclTest.c
index ca2d9cb..ef908a1 100644
--- a/generic/tclTest.c
+++ b/generic/tclTest.c
@@ -1259,7 +1259,7 @@ TestcmdtokenCmd(
nextCommandTokenRefId++;
refPtr->nextPtr = firstCommandTokenRef;
firstCommandTokenRef = refPtr;
- sprintf(buf, "%d", refPtr->id);
+ snprintf(buf, sizeof(buf), "%d", refPtr->id);
Tcl_AppendResult(interp, buf, NULL);
} else {
if (sscanf(argv[2], "%d", &id) != 1) {
@@ -2722,7 +2722,7 @@ ExitProcOdd(
char buf[16 + TCL_INTEGER_SPACE];
int len;
- sprintf(buf, "odd %d\n", (int)PTR2INT(clientData));
+ snprintf(buf, sizeof(buf), "odd %d\n", (int)PTR2INT(clientData));
len = strlen(buf);
if (len != (int) write(1, buf, len)) {
Tcl_Panic("ExitProcOdd: unable to write to stdout");
@@ -2736,7 +2736,7 @@ ExitProcEven(
char buf[16 + TCL_INTEGER_SPACE];
int len;
- sprintf(buf, "even %d\n", (int)PTR2INT(clientData));
+ snprintf(buf, sizeof(buf), "even %d\n", (int)PTR2INT(clientData));
len = strlen(buf);
if (len != (int) write(1, buf, len)) {
Tcl_Panic("ExitProcEven: unable to write to stdout");
@@ -2781,7 +2781,7 @@ TestexprlongCmd(
if (result != TCL_OK) {
return result;
}
- sprintf(buf, ": %ld", exprResult);
+ snprintf(buf, sizeof(buf), ": %ld", exprResult);
Tcl_AppendResult(interp, buf, NULL);
return TCL_OK;
}
@@ -2823,7 +2823,7 @@ TestexprlongobjCmd(
if (result != TCL_OK) {
return result;
}
- sprintf(buf, ": %ld", exprResult);
+ snprintf(buf, sizeof(buf), ": %ld", exprResult);
Tcl_AppendResult(interp, buf, NULL);
return TCL_OK;
}
@@ -4497,7 +4497,7 @@ TestregexpObjCmd(
varName = Tcl_GetString(objv[2]);
TclRegExpRangeUniChar(regExpr, TCL_INDEX_NONE, &start, &end);
- sprintf(resinfo, "%" TCL_Z_MODIFIER "d %" TCL_Z_MODIFIER "d", start, end-1);
+ snprintf(resinfo, sizeof(resinfo), "%" TCL_Z_MODIFIER "d %" TCL_Z_MODIFIER "d", start, end-1);
value = Tcl_SetVar2(interp, varName, NULL, resinfo, 0);
if (value == NULL) {
Tcl_AppendResult(interp, "couldn't set variable \"",
@@ -4511,7 +4511,7 @@ TestregexpObjCmd(
Tcl_RegExpGetInfo(regExpr, &info);
varName = Tcl_GetString(objv[2]);
- sprintf(resinfo, "%" TCL_Z_MODIFIER "d", info.extendStart);
+ snprintf(resinfo, sizeof(resinfo), "%" TCL_Z_MODIFIER "d", info.extendStart);
value = Tcl_SetVar2(interp, varName, NULL, resinfo, 0);
if (value == NULL) {
Tcl_AppendResult(interp, "couldn't set variable \"",
@@ -5284,7 +5284,7 @@ TestgetvarfullnameCmd(
*
* This procedure implements the "gettimes" command. It is used for
* computing the time needed for various basic operations such as reading
* variables, allocating memory, sprintf, converting variables, etc.
*
* Results:
* A standard Tcl result.
@@ -5403,15 +5403,15 @@ GetTimesObjCmd(
fprintf(stderr, " %.3f usec per Tcl_GetInt of \"12345\"\n",
timePer/100000);
- /* sprintf 100000 times */
- fprintf(stderr, "sprintf of 12345 100000 times\n");
+ /* snprintf 100000 times */
+ fprintf(stderr, "snprintf of 12345 100000 times\n");
Tcl_GetTime(&start);
for (i = 0; i < 100000; i++) {
- sprintf(newString, "%d", 12345);
+ snprintf(newString, sizeof(newString), "%d", 12345);
}
Tcl_GetTime(&stop);
timePer = (stop.sec - start.sec)*1000000 + (stop.usec - start.usec);
- fprintf(stderr, " %.3f usec per sprintf of 12345\n",
+ fprintf(stderr, " %.3f usec per snprintf of 12345\n",
timePer/100000);
/* hashtable lookup 100000 times */
@@ -5918,7 +5918,7 @@ TestChannelCmd(
Tcl_Channel chan; /* The opaque type. */
size_t len; /* Length of subcommand string. */
int IOQueued; /* How much IO is queued inside channel? */
- char buf[TCL_INTEGER_SPACE];/* For sprintf. */
+ char buf[TCL_INTEGER_SPACE];/* For snprintf. */
int mode; /* rw mode of the channel */
if (argc < 2) {
@@ -6832,10 +6832,10 @@ TestGetIndexFromObjStructObjCmd(
return TCL_ERROR;
} else if (idx[1] != target) {
char buffer[64];
- sprintf(buffer, "%d", idx[1]);
+ snprintf(buffer, sizeof(buffer), "%d", idx[1]);
Tcl_AppendResult(interp, "index value comparison failed: got ",
buffer, NULL);
- sprintf(buffer, "%d", target);
+ snprintf(buffer, sizeof(buffer), "%d", target);
Tcl_AppendResult(interp, " when ", buffer, " expected", NULL);
return TCL_ERROR;
}
@@ -5284,7 +5284,7 @@ TestgetvarfullnameCmd(
* This procedure implements the "gettimes" command. It is used for
* computing the time needed for various basic operations such as reading
- * variables, allocating memory, sprintf, converting variables, etc.
+ * variables, allocating memory, snprintf, converting variables, etc.
*
* Results: